#ifndef INC_datadefsh
#define INC_datadefsh
/*---------------------------------------------------------------------------
 
  FILENAME:
        datadefs.h
 
  PURPOSE:
        Provide the wview daemon data definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        08/24/03        M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>
#include <signal.h>
#include <math.h>
#include <sys/stat.h>

/*  ... Library include files
*/
#include <sysdefs.h>

/*  ... Local include files
*/
#include "windAverage.h"
#include "sensor.h"

/*  ... data definitions
*/

//  ... for HISTORY_DATA structure
typedef enum
{
    HIST_TYPE_TEMP              = 0,
    HIST_TYPE_HUMID,
    HIST_TYPE_IN_TEMP,
    HIST_TYPE_IN_HUMID,
    HIST_TYPE_DEW,
    HIST_TYPE_WSPEED,
    HIST_TYPE_WDIR,
    HIST_TYPE_HIWSPEED,
    HIST_TYPE_BAROM,
    HIST_TYPE_RAIN,
    HIST_TYPE_WCHILL,
    HIST_TYPE_HINDEX,
    HIST_TYPE_RXCHECK,
    
    HIST_TYPE_BASIC_MAX,
    
    HIST_TYPE_RADIATION         = HIST_TYPE_BASIC_MAX,
    HIST_TYPE_UV,
    HIST_TYPE_ET,
    HIST_TYPE_LEAFTEMP1,
    HIST_TYPE_LEAFTEMP2,
    HIST_TYPE_LEAFWET1,
    HIST_TYPE_LEAFWET2,
    HIST_TYPE_SOILTEMP1,
    HIST_TYPE_SOILTEMP2,
    HIST_TYPE_SOILTEMP3,
    HIST_TYPE_SOILTEMP4,
    HIST_TYPE_EXTRAHUMID1,
    HIST_TYPE_EXTRAHUMID2,
    HIST_TYPE_EXTRATEMP1,
    HIST_TYPE_EXTRATEMP2,
    HIST_TYPE_EXTRATEMP3,
    HIST_TYPE_SOILMOIST1,
    HIST_TYPE_SOILMOIST2,
    HIST_TYPE_SOILMOIST3,
    HIST_TYPE_SOILMOIST4,
    
    HIST_TYPE_EXTENDED_MAX
} HIST_TYPE;

#define HIST_TYPE_MAX(x)    ((x) ? HIST_TYPE_EXTENDED_MAX : HIST_TYPE_BASIC_MAX)


//  ... for NOAA_DATA structure
typedef enum
{
    NOAA_TYPE_TEMP_HIGH         = 0,
    NOAA_TYPE_TEMP_LOW,
    NOAA_TYPE_TEMP_MEAN,
    NOAA_TYPE_RAIN,
    NOAA_TYPE_WIND_MEAN,
    NOAA_TYPE_WIND_HIGH,
    NOAA_TYPE_WIND_DIR,
    NOAA_TYPE_MAX
} NOAA_TYPE;


// internal HILOW data store
typedef struct
{
    WV_SENSOR           sensor[STF_MAX][SENSOR_MAX];
    WAVG                wind[STF_MAX];    

    float               hourchangetemp;             // difference in degrees
    short               hourchangewind;             // difference in mph
    short               hourchangewinddir;          // difference in degrees
    short               hourchangehumid;            // difference in %
    float               hourchangedewpt;            // difference in degrees
    float               hourchangebarom;            // difference in inches

    float               daychangetemp;              // difference in degrees
    short               daychangewind;              // difference in mph
    short               daychangewinddir;           // difference in degrees
    short               daychangehumid;             // difference in %
    float               daychangedewpt;             // difference in degrees
    float               daychangebarom;             // difference in inches

    float               weekchangetemp;             // difference in degrees
    short               weekchangewind;             // difference in mph
    short               weekchangewinddir;          // difference in degrees
    short               weekchangehumid;            // difference in %
    float               weekchangedewpt;            // difference in degrees
    float               weekchangebarom;            // difference in inches

} SENSOR_STORE;


// LOOP_PKT - define the LOOP (current readings) data format for IPM msgs and
//            station sensor polling; those required for auto-archive generation 
//            and HILOW are marked "!" and MUST be provided by the station
typedef struct
{
    // minimum required fields - station must provide these
    float               barometer;              /* ! inches               */
    float               stationPressure;        /* ! inches               */
    float               inTemp;                 /* ! degrees F            */
    float               outTemp;                /* ! degrees F            */
    USHORT              inHumidity;             /* ! percent              */
    USHORT              outHumidity;            /* ! percent              */
    USHORT              windSpeed;              /* ! mph                  */
    USHORT              windDir;                /* ! degrees              */
    USHORT              windGust;               /* ! mph                  */
    USHORT              windGustDir;            /* ! degrees              */
    float               rainRate;               /* ! in/hr                */
    float               sampleRain;             /* ! inches               */
    float               sampleET;               /* ! ET                   */
    USHORT              radiation;              /* ! watts/m^3            */
    USHORT              UV;                     /* ! UV index * 10        */
    float               dewpoint;               /* ! degrees F            */
    float               windchill;              /* ! degrees F            */
    float               heatindex;              /* ! degrees F            */

    // computed values - station should not mess with these
    float               stormRain;              /* inches                 */
    time_t              stormStart;             /* time_t                 */
    float               dayRain;                /* inches                 */
    float               monthRain;              /* inches                 */
    float               yearRain;               /* inches                 */
    float               dayET;                  /* inches                 */
    float               monthET;                /* inches                 */
    float               yearET;                 /* inches                 */
    float               intervalAvgWCHILL;      /* degrees F              */
    short               intervalAvgWSPEED;      /* mph                    */
    USHORT              yearRainMonth;          /* 1-12 Rain Start Month  */
    
    // --- The following may or may not be supported for a given station ---

    // Vantage Pro
    USHORT              rxCheckPercent;         /* 0 - 100                */
    USHORT              tenMinuteAvgWindSpeed;  /* mph                    */
    USHORT              forecastIcon;           /* VP only                */
    USHORT              forecastRule;           /* VP only                */
    USHORT              txBatteryStatus;        /* VP only                */
    USHORT              consBatteryVoltage;     /* VP only                */
    UCHAR               extraTemp1;             /* degrees F + 90         */
    UCHAR               extraTemp2;             /* degrees F + 90         */
    UCHAR               extraTemp3;             /* degrees F + 90         */
    UCHAR               soilTemp1;              /* degrees F + 90         */
    UCHAR               soilTemp2;              /* degrees F + 90         */
    UCHAR               soilTemp3;              /* degrees F + 90         */
    UCHAR               soilTemp4;              /* degrees F + 90         */
    UCHAR               leafTemp1;              /* degrees F + 90         */
    UCHAR               leafTemp2;              /* degrees F + 90         */
    UCHAR               extraHumid1;            /* percent                */
    UCHAR               extraHumid2;            /* percent                */
    UCHAR               soilMoist1;
    UCHAR               soilMoist2;
    UCHAR               leafWet1;
    UCHAR               leafWet2;
    UCHAR               pad1;
    
    // Vaisala WXT-510
    float               wxt510Hail;             /* inches                 */
    float               wxt510Hailrate;         /* in/hr                  */
    float               wxt510HeatingTemp;      /* degrees F              */
    float               wxt510HeatingVoltage;   /* volts                  */
    float               wxt510SupplyVoltage;    /* volts                  */
    float               wxt510ReferenceVoltage; /* volts                  */

    }__attribute__ ((packed)) LOOP_PKT;


//  ... this retrieves historical summations from the dbfGetAverages method
typedef struct
{
    int                 samples;
    int                 startYear;
    int                 startMonth;
    int                 startDay;
    int                 startHour;
    int                 startMin;
    float               values[HIST_TYPE_EXTENDED_MAX];
}__attribute__ ((packed)) HISTORY_DATA;


//  ... this structure retrieves NOAA data from the dbfGetNoaaDay utility
//  ... and defines a record in the noaa.dat file
//  ... (the file is space delimited ASCII)
typedef struct
{
    short           year;
    short           month;
    short           day;
    float           meanTemp;
    float           highTemp;
    char            highTempTime[8];
    float           lowTemp;
    char            lowTempTime[8];
    float           heatDegDays;
    float           coolDegDays;
    float           rain;
    float           avgWind;
    float           highWind;
    char            highWindTime[8];
    int             domWindDir;
}__attribute__ ((packed)) NOAA_DAY_REC;


/*  ... API methods
*/


#endif

