#ifndef INC_servicesh
#define INC_servicesh
/*---------------------------------------------------------------------------
 
  FILENAME:
        services.h
 
  PURPOSE:
        Provide the wview daemon application sevices definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        08/24/03        M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>
#include <signal.h>
#include <math.h>
#include <sys/stat.h>

/*  ... Library include files
*/
#include <sysdefs.h>

/*  ... Local include files
*/
#include <datadefs.h>


/*  ... API definitions
*/

/*  ... request types for the WVIEW_MSG_TYPE_REQUEST message
*/
typedef enum
{
    WVIEW_RQST_TYPE_ARCHIVE_PATH        = 1,
    WVIEW_RQST_TYPE_HILOW_DATA          = 2,
    WVIEW_RQST_TYPE_LOOP_DATA           = 3,
    WVIEW_RQST_TYPE_DST_ANNOUNCE        = 4
} WVIEW_RQST_TYPES;

/*  ... message types:
    ... currently the wviewd daemon only receives the WVIEW_MSG_TYPE_REQUEST
    ... message and sends the other types
*/
typedef enum
{
    WVIEW_MSG_TYPE_REQUEST              = 1,
    WVIEW_MSG_TYPE_ARCHIVE_PATH         = 2,
    WVIEW_MSG_TYPE_HILOW_DATA           = 3,
    WVIEW_MSG_TYPE_LOOP_DATA            = 4,
    WVIEW_MSG_TYPE_LOOP_DATA_SVC        = 5,
    WVIEW_MSG_TYPE_ARCHIVE_NOTIFY       = 6,

} WVIEW_MSG_TYPES;


/*  ... WVIEW_MSG_TYPE_REQUEST
    ... requestType is one of WVIEW_RQST_TYPES;
    ... will cause that msg/action to be sent/performed
*/
typedef struct
{
    int             requestType;
    int             enable;                     // enable/disable msg reception
                                                // for "SVC" requests
}__attribute__ ((packed)) WVIEW_MSG_REQUEST;

/*  ... WVIEW_MSG_TYPE_ARCHIVE_PATH
    ... returns the archive path and other info
*/
typedef struct
{
    char            archivePath[256];
    time_t          lastArcTime;
    short           archiveInterval;
    short           latitude;
    short           longitude;
    short           elevation;

}__attribute__ ((packed)) WVIEW_MSG_ARCHIVE_PATH;

/*  ... WVIEW_MSG_TYPE_HILOW_DATA
    ... returns the most recent HILOW data
*/
typedef struct
{
    SENSOR_STORE    hilowData;

}__attribute__ ((packed)) WVIEW_MSG_HILOW_DATA;

/*  ... WVIEW_MSG_TYPE_LOOP_DATA
    ... returns the most recent loop data
*/
typedef struct
{
    LOOP_PKT        loopData;

}__attribute__ ((packed)) WVIEW_MSG_LOOP_DATA;

/*  ... WVIEW_MSG_TYPE_ARCHIVE_NOTIFY
    ... notification of the reception of an archive record from the VP console
    ... and pertinent data from that record
*/
typedef struct
{
    USHORT          archiveDate;            // last archive rec date/time
    USHORT          archiveTime;
    int             intemp;
    int             inhumidity;
    int             temp;
    int             humidity;
    int             barom;
    int             stationPressure;
    int             winddir;
    int             wspeed;
    int             hiwspeed;
    int             rainHour;
    int             rainDay;
    int             dewpoint;
    int             rxPercent;

}__attribute__ ((packed)) WVIEW_MSG_ARCHIVE_NOTIFY;


#endif
