#ifndef INC_htmlh
#define INC_htmlh
/*---------------------------------------------------------------------------
 
  FILENAME:
        html.h
 
  PURPOSE:
        Provide the wview HTML generator definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        08/27/03        M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>

/*  ... Library include files
*/
#include <sysdefs.h>
#include <radsemaphores.h>
#include <radbuffers.h>
#include <radqueue.h>
#include <radtimers.h>
#include <radevents.h>
#include <radtimeUtils.h>
#include <radsysutils.h>
#include <radprocess.h>
#include <radstates.h>
#include <radmsgRouter.h>

/*  ... Local include files
*/
#include <sensor.h>
#include <dbfiles.h>
#include <datadefs.h>
#include <services.h>
#include <htmlMgr.h>
#include <noaaGenerate.h>


#define __DEBUG         TRUE


/*  ... API definitions
*/
#define SECONDS_IN_INTERVAL(x)          (x * 60)

#define HTML_DST_TIMER_INTERVAL         (1000*90)       // 90 seconds


/*  !!!!!!!!!!!!!!!!!!  HIDDEN, NOT FOR API USE  !!!!!!!!!!!!!!!!!!
*/
#define TIMER_GENERATE          1
#define TIMER_DST               2


typedef struct
{
    pid_t           myPid;
    char            pidFile[128];
    char            fifoFile[128];
    char            daemonQname[128];
    char            configFile[128];
    char            archivePath[256];
    int             archiveInterval;
    int             isMetricUnits;
    int             isMetricRainMM;
    char            imagePath[256];
    char            htmlPath[256];
    int             isExtendedData;
    STATES_ID       stateMachine;
    char            stationName[64];
    char            stationCity[64];
    char            stationState[64];
    int             arcrecDaysToKeep;
    char            mphaseIncrease[32];
    char            mphaseDecrease[32];
    char            mphaseFull[32];
    TIMER_ID        timer;
    TIMER_ID        dstTimer;
    struct timeval  nextGenerationTime;
    int             timerInterval;
    int             startOffset;
    int             histLastHour;
    int             histLastDay;
    HTML_MGR_ID     mgrId;
    NOAA_ID         noaaId;
    int             numDataReceived;
    int             dstChangeFlag;
    int             exiting;
} HTML_WORK;


typedef enum
{
    HTML_STATE_IDLE             = 1,
    HTML_STATE_ARCHIVE,
    HTML_STATE_RUN,
    HTML_STATE_DATA,
    HTML_STATE_ERROR
} HTML_STATES;


extern int htmlIdleState (int state, void *stimulus, void *data);
extern int htmlArchiveState (int state, void *stimulus, void *data);
extern int htmlRunState (int state, void *stimulus, void *data);
extern int htmlDataState (int state, void *stimulus, void *data);
extern int htmlErrorState (int state, void *stimulus, void *data);


/*  !!!!!!!!!!!!!!!!!!!!  END HIDDEN SECTION  !!!!!!!!!!!!!!!!!!!!!
*/



/* ... API function prototypes
*/

#endif
