#ifndef INC_htmlgenerateh
#define INC_htmlgenerateh
/*---------------------------------------------------------------------------
 
  FILENAME:
        htmlGenerateh.h
 
  PURPOSE:
        Provide the wview HTML generator definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        08/30/03        M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>
#include <signal.h>

/*  ... Library include files
*/
#include <sysdefs.h>
#include <radsemaphores.h>
#include <radbuffers.h>
#include <radlist.h>

/*  ... Local include files
*/
#include <dbfiles.h>
#include <datadefs.h>
#include <services.h>

#include <htmlMgr.h>
#include <glmultichart.h>


/*  ... API definitions
*/

#define BUCKET_DFLT_BG              0xF5F5F5
#define BUCKET_DFLT_BUCKET          0x000000
#define BUCKET_DFLT_CONTENT         0x4282B4
#define BUCKET_DFLT_HIGH            0xFF0000
#define BUCKET_DFLT_LOW             0x00BFFF
#define BUCKET_DFLT_TITLEFG         0x000000
#define BUCKET_DFLT_TITLEBG         0xD8D8D8
#define BUCKET_DFLT_TEXT            0x000000

#define CHART_DFLT_BG               0xF5F5F5
#define CHART_DFLT_CHART            0xD8D8D8
#define CHART_DFLT_GRID             0xA0A000
#define CHART_DFLT_LINE             0x4282B4
#define CHART_DFLT_2ND_LINE         0xB44242
#define CHART_DFLT_3RD_LINE         0x42B442
#define CHART_DFLT_TITLEFG          0x000000
#define CHART_DFLT_TITLEBG          0xD8D8D8
#define CHART_DFLT_TEXT             0x000000



/*  !!!!!!!!!!!!!!!!!!  HIDDEN, NOT FOR API USE  !!!!!!!!!!!!!!!!!!
*/

// utility macros for the VP packed date format
#define VP_YEAR(x)                  (((x >> 9) & 0x7F) + 2000)
#define VP_MONTH(x)                 ((x >> 5) & 0x0F)
#define VP_DAY(x)                   (x & 0x1F)


struct xyCoords
{
    float       x;
    float       y;
};


/*  !!!!!!!!!!!!!!!!!!!!  END HIDDEN SECTION  !!!!!!!!!!!!!!!!!!!!!
*/


/* ... API function prototypes
*/
extern int htmlgenHTMLFiles (HTML_MGR_ID id);

extern int htmlgenMesonetFile (HTML_MGR_ID id, WVIEW_MSG_ARCHIVE_NOTIFY *armsg);

extern int htmlGenPngBucket
(
    char            *fname,
    int             isMetric,
    float           value,
    float           low,
    float           high,
    char            *title,
    char            *units,
    int             decimalPlaces,
    float           lowScale,
    float           highScale
);

extern int htmlGenPngRainBucket
(
    char            *fname,
    int             isMetric,
    float           value,
    float           low,
    float           high,
    char            *title,
    char            *units,
    int             decimalPlaces,
    float           lowScale,
    float           highScale
);

extern int htmlGenPngBaromBucket
(
    char            *fname,
    float           value,
    float           low,
    float           high,
    char            *title,
    char            *units,
    int             decimalPlaces
);

extern int htmlGenMetricPngBaromBucket
(
    char                *fname,
    float               value,
    float               low,
    float               high,
    char                *title,
    char                *units,
    int                 decimalPlaces
);

extern int htmlGenPngPercentBucket
(
    char            *fname,
    int             isMetric,
    float           value,
    float           low,
    float           high,
    char            *title,
    char            *units,
    int             decimalPlaces
);

#define CHART_MAX_TEMP(x)       (x ? (float)15.0 : (float)60.0)
#define CHART_MIN_TEMP(x)       (x ? (float)0.0 : (float)40.0)
extern int htmlGenPngChart
(
    char            *fname,
    int             isMetric,
    float           *values,
    int             xHashes,
    float           ymin,
    float           ymax,
    float           ystep,
    char            *labels[],
    int             numValues,
    char            *title,
    char            *units,
    int             decimalPlaces
);

extern int htmlGenPngBarChart
(
    char            *fname,
    int             isMetric,
    float           *values,
    int             xHashes,
    float           ymin,
    float           ymax,
    float           ystep,
    char            *labels[],          // size=numValues+1 for last label
    int             numValues,
    char            *title,
    char            *units,
    int             decimalPlaces,
    int             numPointsPerBar,
    int             numBars,
    int             numPointsInFirstBar
);

extern int htmlGenPngPercentChart
(
    char            *fname,
    int             isMetric,
    float           *values,
    int             xHashes,
    char            *labels[],
    int             numValues,
    char            *title
);

extern int htmlGenPngMultiChart
(
    char                    *fname,
    int                     isMetric,
    MC_DATASET              *datasets,
    int                     numDataSets,
    int                     xHashes,
    float                   min,
    float                   max,
    float                   step,
    char                    *labels[],
    int                     numValues,
    char                    *units,
    int                     decimalPlaces
);

extern int htmlGenPngWDIRChart
(
    char            *fname,
    int             isMetric,
    float           *values,
    int             xHashes,
    char            *labels[],
    int             numValues,
    char            *title,
    char            *units,
    int             decimalPlaces
);

extern int htmlGenPngDialWind
(
    char                *fname,
    int                 isMetricUnits,
    int                 direction,          // 0 - 359 degrees
    int                 highDirection,      // 0-359 degrees
    int                 speed,
    int                 highSpeed,
    char                *title
);

extern int htmlGenPngDialTemperature
(
    char                *fname,
    int                 isMetricUnits,
    float               temperature,        // -40 to 140 degrees, 180 total
    float               low,
    float               high,
    float               feelsLike,
    char                *title,
    char                *units
);

extern int htmlGenPngDialHumidity
(
    char                *fname,
    float               humidity,           // 0 to 100 %, 100 total
    float               low,
    float               high,
    char                *title
);

extern int htmlGenPngDialNetRain
(
    char                *fname,
    int                 isMetricUnits,
    int                 isMetricRainMM,
    float               rain,
    float               et,               
    char                *title,
    char                *units
);

#endif
