#ifndef INC_sqldh
#define INC_sqldh
/*---------------------------------------------------------------------------
 
  FILENAME:
        sqld.h
 
  PURPOSE:
        Provide the wview SQL daemon process definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        12/22/2005      M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2005, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>

/*  ... Library include files
*/
#include <sysdefs.h>
#include <radsystem.h>
#include <radsemaphores.h>
#include <radbuffers.h>
#include <radlist.h>
#include <radqueue.h>
#include <radtimers.h>
#include <radevents.h>
#include <radtimeUtils.h>
#include <radsysutils.h>
#include <radprocess.h>
#include <radsocket.h>
#include <radconffile.h>
#include <radmsgRouter.h>

/*  ... Local include files
*/
#include <sysdefs.h>
#include <datadefs.h>
#include <dbfiles.h>
#include <dbdatabase.h>
#include <services.h>


#define __DEBUG         TRUE


/*  ... API definitions
*/

/*  !!!!!!!!!!!!!!!!!!  HIDDEN, NOT FOR API USE  !!!!!!!!!!!!!!!!!!
*/

// how long to wait after an archive notify to sync the database
#define SQLD_TIMER_DELAY_VALUE          15000

// how long to wait between DB open tries
#define SQLD_TIMER_DBOPEN_VALUE         5000


enum SQLD_STATES
{
    SQLD_STATE_SYNC             = 1,
    SQLD_STATE_IDLE
};

typedef struct
{
    pid_t           myPid;
    char            configFile[128];
    char            pidFile[128];
    char            fifoFile[128];
    char            wviewdir[128];
    char            archivePath[256];
    TIMER_ID        syncTimer;
    int             sqldbEnable;
    int             sqldbExtended;
    int             sqldbMetric;
    char            sqldbHost[128];
    char            sqldbUser[64];
    char            sqldbPassword[64];
    char            sqldatabase[64];
    char            sqldbTable[64];
    int             inMainLoop;
    int             state;
    int             initialSync;
    USHORT          lastDate;
    USHORT          lastTime;
    ULONG           inserts;
    ULONG           duplicates;
    ULONG           errors;
    int             exiting;
} WVIEW_SQLD_WORK;

/*  !!!!!!!!!!!!!!!!!!!!  END HIDDEN SECTION  !!!!!!!!!!!!!!!!!!!!!
*/



/* ... API function prototypes
*/



#endif
