#ifndef INC_sshutilsh
#define INC_sshutilsh
/*---------------------------------------------------------------------------
 
  FILENAME:
        sshUtils.h
 
  PURPOSE:
        Provide the ssh utility definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        05/28/2005      M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>

/*  ... Library include files
*/
#include <sysdefs.h>
#include <radsemaphores.h>
#include <radbuffers.h>
#include <radtimers.h>
#include <radlist.h>
#include <radtimeUtils.h>
#include <radsysutils.h>

/*  ... Local include files
*/
#include <datadefs.h>



/*  ... API definitions
*/


/*  !!!!!!!!!!!!!!!!!!  HIDDEN, NOT FOR API USE  !!!!!!!!!!!!!!!!!!
*/

typedef struct
{
    NODE        node;
    char        host[128];
    char        src[128];
    char        dest[128];
    int         interval;
    int         currentCount;
} *SSH_RULE_ID;


typedef struct
{
    char        rsyncPath[128];
    char        confFile[128];
    RADLIST     rules;
} *SSH_ID;


/*  !!!!!!!!!!!!!!!!!!!!  END HIDDEN SECTION  !!!!!!!!!!!!!!!!!!!!!
*/



/* ... API function prototypes
*/
extern SSH_ID sshUtilsInit (char *confFilePath);

//  ... process the rules list; returns number of rules successfully sent
extern int sshUtilsSendFiles (SSH_ID id, char *workdir);

extern void sshUtilsExit (SSH_ID);


#endif
