#ifndef INC_daemonh
#define INC_daemonh
/*---------------------------------------------------------------------------
 
  FILENAME:
        daemon.h
 
  PURPOSE:
        Provide the wview daemon definitions.
 
  REVISION HISTORY:
        Date            Engineer        Revision        Remarks
        08/14/03        M.S. Teel       0               Original
 
  NOTES:
        
 
  LICENSE:
        Copyright (c) 2004, Mark S. Teel (mark@teel.ws)
  
        This source code is released for free distribution under the terms 
        of the GNU General Public License.
  
----------------------------------------------------------------------------*/

/*  ... System include files
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>
#include <signal.h>

/*  ... Library include files
*/
#include <sysdefs.h>
#include <radsemaphores.h>
#include <radbuffers.h>
#include <radqueue.h>
#include <radtimers.h>
#include <radevents.h>
#include <radtimeUtils.h>
#include <radprocess.h>
#include <radstates.h>
#include <radmsgRouter.h>

/*  ... Local include files
*/
#include <dbfiles.h>
#include <services.h>


/*  !!!!!!!!!!!!!!!!!!  HIDDEN, NOT FOR API USE  !!!!!!!!!!!!!!!!!!
*/

// define the weather station interface abstraction
#define WV_QUEUE_INPUT          1
#define WV_QUEUE_OUTPUT         2

typedef struct _wview_medium
{
    int             fd;
    void            *workData;
    int             (*init) (struct _wview_medium *medium, char *deviceName);
    void            (*exit) (struct _wview_medium *medium);
    int             (*read) (struct _wview_medium *medium, void *bfr, int len, int timeout);
    int             (*write) (struct _wview_medium *medium, void *buffer, int length);
    void            (*flush) (struct _wview_medium *medium, int queue);
    void            (*txdrain) (struct _wview_medium *medium);
} WVIEW_MEDIUM;


// 1 hour in ms
#define WVD_TIME_SYNC_INTERVAL          (1 * 60 * 60 * 1000)

// initial console wakeup number of attempts
#define WVD_INITIAL_WAKEUP_TRIES        20

// time to wait before attempting read recovery
#define WVD_READ_RECOVER_INTERVAL       2500

#define WVD_READ_RECOVER_MAX_RETRIES    5


// the wview daemon work area
typedef struct
{
    pid_t           myPid;
    WVIEW_MEDIUM    medium;
    void            *stationData;               // station-specific data store
    int             runningFlag;
    int             stationGeneratesArchives;
    char            pidFile[128];
    char            fifoFile[128];
    char            configFile[128];
    char            stationInterface[16];
    char            stationDevice[128];
    char            stationHost[128];
    int             stationPort;
    int             stationRainSeasonStart;
    float           stationRainStormTrigger;
    int             stationRainStormIdleHours;
    char            archivePath[256];
    USHORT          archiveInterval;
    short           latitude;
    short           longitude;
    short           elevation;
    USHORT          archiveDate;
    USHORT          archiveTime;
    ARCHIVE_RECORD  lastGoodArchiveRecord;
    TIMER_ID        archiveTimer;
    TIMER_ID        cdataTimer;
    TIMER_ID        pushTimer;
    TIMER_ID        syncTimer;
    TIMER_ID        ifTimer;
    int             cdataInterval;
    int             pushInterval;
    SENSOR_STORE    sensors;
    LOOP_PKT        loopPkt;                    // for IPM pkts
    int             numReadRetries;
    int             archiveRqstPending;
    int             lastHighWindSpeed;
    
    // SQLDB
    int             sqldbEnable;
    int             sqldbExtended;
    int             sqldbMetric;
    char            sqldbHost[128];
    char            sqldbUser[64];
    char            sqldbPassword[64];
    char            sqldatabase[64];
    char            sqldbTable[64];

    int             exiting;

} WVIEWD_WORK;


/*  !!!!!!!!!!!!!!!!!!!!  END HIDDEN SECTION  !!!!!!!!!!!!!!!!!!!!!
*/


#endif

