#!/bin/sh
###########################################################################
#
# File:           wviewconfig.sh
#
# Description:    Provide a script to interactively configure a wview 
#                 installation.
#
# Usage:          wviewconfig (must be root)
#
# History:
# Engineer	  Date	    Ver   Comments
# MS Teel	  06/20/05   1    Original
#
###########################################################################


################### MACROS ######################
#
WVIEWD_PID=/var/wview/wviewd.pid
WVIEW_CONF_DIR=/etc/wview
STATION_TYPE=VantagePro

# First test to make sure wview is not running...
if [ -f $WVIEWD_PID ]; then
    echo "wviewd is running - stop wview before running this script..."
    exit 3
fi

echo "################################################################################"
echo " !!!!!!!!!!!!!!!!         READ THIS BEFORE PROCEEDING         !!!!!!!!!!!!!!!!"
echo ""
echo "--> System Configuration for wview"
echo ""
echo "--> Values in parenthesis are your existing values (if they exist) or defaults - "
echo "    they will be used if you just hit enter at the prompt..."
echo ""
echo "--> Note: This script will save existing wview.conf, htmlgen.conf, wvcwop.conf"
echo "          and wvwunder.conf files to *.old before writing the new files based on "
echo "          your answers here - if that is not what you want, hit CTRL-C now to"
echo "          abort this script!"
echo ""
echo "################################################################################"
echo ""
echo -n "pausing 3 seconds "
sleep 1
echo -n "."
sleep 1
echo -n "."
sleep 1
echo "."
echo ""

# determine what kind of station they have built for...
echo "-------------------------------------------------------------"
echo "Valid Station Types: VantagePro, Generic"
echo "Generic refers to stations without location or archive interval parameter storage -"
echo "in this case you must enter location and archive interval now..."
echo "What weather station do you have (one of VantagePro, Generic):"
echo -n "($STATION_TYPE): "
read INVAL
if [ "" != "$INVAL" ]; then
    STATION_TYPE=$INVAL
fi

# verify the station type
if [ "$STATION_TYPE" != "VantagePro" ]; then
    if [ "$STATION_TYPE" != "Generic" ]; then
        echo "Invalid station type $STATION_TYPE given, try again!"
        exit 1
    fi
fi

# Try to obtain the current values (if found) to use for the default choices
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    MEDIUM=`cat $WVIEW_CONF_DIR/wview.conf | \
            grep STATION_INTERFACE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DEVNAME=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_DEV | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    ETHHOST=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_HOST | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    ETHPORT=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_PORT | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    RAIN_SEASON_START=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_RAIN_SEASON_START | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    STATION_RAIN_STORM_TRIGGER_START=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_RAIN_STORM_TRIGGER_START | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    STATION_RAIN_STORM_IDLE_STOP=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep STATION_RAIN_STORM_IDLE_STOP | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    ARCPATH=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep ARCHIVE_PATH | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    SENSORPOLL=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep POLL_INTERVAL | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    if [ "" = "$SENSORPOLL" ]; then
        SENSORPOLL=`cat $WVIEW_CONF_DIR/wview.conf | \
                     grep ARCHIVE_INTERVAL | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    PUSHINT=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep PUSH_INTERVAL | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    VERBOSE=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep VERBOSE_MSGS | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi

# VantagePro Only
if [ "$STATION_TYPE" = "VantagePro" ]; then
    if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
        RXCHECK=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep DO_RXCHECK | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
fi

# Generic Station Info (Non-VP)
if [ "$STATION_TYPE" = "Generic" ]; then
    if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
        STATION_ELEVATION=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep STATION_ELEVATION | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
    if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
        STATION_LATITUDE=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep STATION_LATITUDE | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
    if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
        STATION_LONGITUDE=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep STATION_LONGITUDE | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
    if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
        STATION_ARCHIVE_INTERVAL=`cat $WVIEW_CONF_DIR/wview.conf | \
                 grep STATION_ARCHIVE_INTERVAL | \
                awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
    fi
fi

if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DATABASE=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_ENABLE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBEXTEND=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_EXTENDED_INFO | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBMETRIC=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_STORE_METRIC | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBHOST=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_HOST | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBUSER=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_USERNAME | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBPASSWD=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_PASSWORD | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBNAME=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_DB_NAME | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    DBTABLE=`cat $WVIEW_CONF_DIR/wview.conf | \
             grep SQLDB_TABLE_NAME | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi


if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    STANAME=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep STATION_NAME | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    STACITY=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep STATION_CITY | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    STASTATE=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep STATION_STATE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    IMAGEPATH=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep IMAGE_PATH | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    HTMLPATH=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep HTML_PATH | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    GENOFFSET=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep START_OFFSET | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    GENINT=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep GENERATE_INTERVAL | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    GENMETRIC=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep METRIC_UNITS | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    METRIC_USE_RAIN_MM=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep METRIC_USE_RAIN_MM | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    GENEXTEND=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep EXTENDED_DATA | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    RECSTOKEEP=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep ARCHIVE_BROWSER_FILES_TO_KEEP | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    MPHASEWAX=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep MPHASE_INCREASE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    MPHASEWANE=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep MPHASE_DECREASE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    MPHASEFULL=`cat $WVIEW_CONF_DIR/htmlgen.conf | \
             grep MPHASE_FULL | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi

if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSSIGN=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_CALL_SIGN | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSSERVER1=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_SERVER1 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSPORT1=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_PORTNO1 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSSERVER2=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_SERVER2 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSPORT2=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_PORTNO2 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSSERVER3=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_SERVER3 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    APRSPORT3=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep APRS_PORTNO3 | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    CWOPLAT=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep LATITUDE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    CWOPLONG=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep LONGITUDE | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    CWOPLOGWX=`cat $WVIEW_CONF_DIR/wvcwop.conf | \
             grep LOG_WX_PACKET | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi

if [ -f $WVIEW_CONF_DIR/wvwunder.conf ]; then
    WUNDERID=`cat $WVIEW_CONF_DIR/wvwunder.conf | \
             grep STATIONID | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi
if [ -f $WVIEW_CONF_DIR/wvwunder.conf ]; then
    WUNDERPASSWD=`cat $WVIEW_CONF_DIR/wvwunder.conf | \
             grep PASSWORD | \
            awk '{if (index($0,"\t") != 0) $0=substr($0,1,index($0,"\t"));if (index($0," ") != 0) $0=substr($0,1,index($0," "));if (substr($1,1,1) != "#") {$1=substr($1,index($1,"=")+1);print}}'`
fi

# if values were not found in the existing conf files, use some logical
# default values
if [ "" = "$MEDIUM" ]; then
    MEDIUM=serial
fi
if [ "" = "$DEVNAME" ]; then
    DEVNAME=/dev/ttyS0
fi
if [ "" = "$ETHHOST" ]; then
    ETHHOST=changeME
fi
if [ "" = "$ETHPORT" ]; then
    ETHPORT=changeME
fi
if [ "" = "$RAIN_SEASON_START" ]; then
    RAIN_SEASON_START=1
fi
if [ "" = "$STATION_RAIN_STORM_TRIGGER_START" ]; then
    STATION_RAIN_STORM_TRIGGER_START=0.05
fi
if [ "" = "$STATION_RAIN_STORM_IDLE_STOP" ]; then
    STATION_RAIN_STORM_IDLE_STOP=12
fi
if [ "" = "$ARCPATH" ]; then
    ARCPATH=/var/wview/archive
fi
if [ "" = "$SENSORPOLL" ]; then
    SENSORPOLL=15000
fi
if [ "" = "$PUSHINT" ]; then
    PUSHINT=60000
fi
if [ "" = "$VERBOSE" ]; then
    VERBOSE=00000011
fi
# VantagePro Only
if [ "$STATION_TYPE" = "VantagePro" ]; then
    if [ "" = "$RXCHECK" ]; then
        RXCHECK=1
    fi
fi
# Generic - non-VP
if [ "$STATION_TYPE" = "Generic" ]; then
    if [ "" = "$STATION_ELEVATION" ]; then
        STATION_ELEVATION=changeME
    fi
    if [ "" = "$STATION_LATITUDE" ]; then
        STATION_LATITUDE=changeME
    fi
    if [ "" = "$STATION_LONGITUDE" ]; then
        STATION_LONGITUDE=changeME
    fi
    if [ "" = "$STATION_ARCHIVE_INTERVAL" ]; then
        STATION_ARCHIVE_INTERVAL=5
    fi
fi
if [ "" = "$DATABASE" ]; then
    DATABASE=0
fi
if [ "" = "$DBEXTEND" ]; then
    DBEXTEND=0
fi
if [ "" = "$DBMETRIC" ]; then
    DBMETRIC=0
fi
if [ "" = "$DBHOST" ]; then
    DBHOST=changeME
fi
if [ "" = "$DBUSER" ]; then
    DBUSER=changeME
fi
if [ "" = "$DBPASSWD" ]; then
    DBPASSWD=changeME
fi
if [ "" = "$DBNAME" ]; then
    DBNAME=wviewDB
fi
if [ "" = "$DBTABLE" ]; then
    DBTABLE=archive
fi

if [ "" = "$STANAME" ]; then
    STANAME=changeME
fi
if [ "" = "$STACITY" ]; then
    STACITY=changeME
fi
if [ "" = "$STASTATE" ]; then
    STASTATE=changeME
fi
if [ "" = "$IMAGEPATH" ]; then
    IMAGEPATH=/var/wview/img
fi
if [ "" = "$HTMLPATH" ]; then
    HTMLPATH=$WVIEW_CONF_DIR/html
fi
if [ "" = "$GENOFFSET" ]; then
    GENOFFSET=0
fi
if [ "" = "$GENINT" ]; then
    GENINT=1
fi
if [ "" = "$GENMETRIC" ]; then
    GENMETRIC=0
fi
if [ "" = "$METRIC_USE_RAIN_MM" ]; then
    METRIC_USE_RAIN_MM=0
fi
if [ "" = "$GENEXTEND" ]; then
    GENEXTEND=0
fi
if [ "" = "$RECSTOKEEP" ]; then
    RECSTOKEEP=3
fi
if [ "" = "$MPHASEWAX" ]; then
    MPHASEWAX=Waxing
fi
if [ "" = "$MPHASEWANE" ]; then
    MPHASEWANE=Waning
fi
if [ "" = "$MPHASEFULL" ]; then
    MPHASEFULL=Full
fi

if [ "" = "$APRSSIGN" ]; then
    APRSSIGN=changeME
fi
if [ "" = "$APRSSERVER1" ]; then
    APRSSERVER1=changeME
fi
if [ "" = "$APRSPORT1" ]; then
    APRSPORT1=23
fi
if [ "" = "$APRSSERVER2" ]; then
    APRSSERVER2=changeME
fi
if [ "" = "$APRSPORT2" ]; then
    APRSPORT2=23
fi
if [ "" = "$APRSSERVER3" ]; then
    APRSSERVER3=changeME
fi
if [ "" = "$APRSPORT3" ]; then
    APRSPORT3=23
fi
if [ "" = "$CWOPLAT" ]; then
    CWOPLAT=changeME
fi
if [ "" = "$CWOPLONG" ]; then
    CWOPLONG=changeME
fi
if [ "" = "$CWOPLOGWX" ]; then
    CWOPLOGWX=0
fi

if [ "" = "$WUNDERID" ]; then
    WUNDERID=changeME
fi
if [ "" = "$WUNDERPASSWD" ]; then
    WUNDERPASSWD=changeME
fi

#################### MAIN #######################
#

################################################################################
echo "################################################################################"
echo "--> wviewd Configuration ($WVIEW_CONF_DIR/wview.conf):"
echo ""


echo "-------------------------------------------------------------" 
echo "--Note-- USB is considered serial (/dev/ttyUSBx, /dev/tty.SLAB_USBtoUART, etc.)"
echo "Physical Interface the weather station is connected to (one of serial or ethernet)"
echo -n "($MEDIUM): "
read INVAL
if [ "" != "$INVAL" ]; then
    MEDIUM=$INVAL
fi

# the next few depend on the medium selected
if [ "$MEDIUM" = "serial" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Serial port (device) the weather station is connected to (/dev/ttyS0, /dev/cuaa0, /dev/ttyUSBx, /dev/tty.SLAB_USBtoUART, etc.)"
    echo -n "($DEVNAME): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        DEVNAME=$INVAL
    fi
elif [ "$MEDIUM" = "ethernet" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Hostname or IP address the weather station is connected to (i.e. xyplex1 or 10.11.12.13)"
    echo -n "($ETHHOST): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        ETHHOST=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note-- This is dependent upon the terminal server used - consult your terminal server documentation"
    echo "TCP port the weather station is connected to on $ETHHOST (i.e. 2101)"
    echo -n "($ETHPORT): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        ETHPORT=$INVAL
    fi
else
    echo "$MEDIUM is not a valid physical interface - must be one of serial or ethernet!"
    exit 7
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Station Rain Season Start Month (1 - 12):"
echo -n "($RAIN_SEASON_START): "
read INVAL
if [ "" != "$INVAL" ]; then
    RAIN_SEASON_START=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Station rain storm start trigger (rainfall rate in inches/hour):"
echo -n "($STATION_RAIN_STORM_TRIGGER_START): "
read INVAL
if [ "" != "$INVAL" ]; then
    STATION_RAIN_STORM_TRIGGER_START=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Station rain storm stop time (hours without any rainfall which will end the storm):"
echo -n "($STATION_RAIN_STORM_IDLE_STOP): "
read INVAL
if [ "" != "$INVAL" ]; then
    STATION_RAIN_STORM_IDLE_STOP=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- Under normal circumstances, the default selection should be used"
echo "Where to store archive files (*.wlk) - this must be local to the wview server"
echo -n "($ARCPATH): "
read INVAL
if [ "" != "$INVAL" ]; then
    ARCPATH=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- This value must be one of 10000, 15000 or 30000 (milliseconds)"
echo "How often should wviewd poll the weather station for current conditions (milliseconds)?"
echo -n "($SENSORPOLL): "
read INVAL
if [ "" != "$INVAL" ]; then
    SENSORPOLL=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- This value must be >= 15000 (milliseconds)"
echo "How often should wviewd provide current conditions data to clients such as wvalarmd (milliseconds)?"
echo -n "($PUSHINT): "
read INVAL
if [ "" != "$INVAL" ]; then
    PUSHINT=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- error messages are not affected by this setting"
echo "Daemon Verbose Log Mask:"
echo "1 bit per daemon, 1 enables verbose logging, 0 disables"
echo "Bit definitions:"
echo "00000001     - wviewd"
echo "00000010     - htmlgend"
echo "00000100     - wvalarmd"
echo "00001000     - wviewftpd"
echo "00010000     - wviewsshd"
echo "00100000     - wvcwopd"
echo "01000000     - wvwunderd"
echo "11111111     - All On"
echo "Verbose diagnostic log messages per-daemon bitmask (8 characters, 0 or 1 only):"
echo -n "($VERBOSE): "
read INVAL
if [ "" != "$INVAL" ]; then
    VERBOSE=$INVAL
fi

# VantagePro Only
if [ "$STATION_TYPE" = "VantagePro" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note--  enabling this can occasionally cause serial IF problems -"
    echo "--Note--  if you are having WAKEUP console errors, try disabling this"
    echo "Should wview generate RX check data (populate rxCheck.png chart) (0 or 1)?"
    echo -n "($RXCHECK): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        RXCHECK=$INVAL
    fi
fi

# Generic - non-VP
if [ "$STATION_TYPE" = "Generic" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Weather station elevation (feet above sea level)?"
    echo -n "($STATION_ELEVATION): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$STATION_ELEVATION" ]; then
            echo "Station elevation must be specified!"
            exit 8
        fi
    else
        STATION_ELEVATION=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note--  This is given in decimal degrees NORTH (-90.00 to 90.00) -"
    echo "--Note--  Examples: -46.31 (46.31 degrees SOUTH), 33.4 (33.4 degrees NORTH)"
    echo "Weather station latitude?"
    echo -n "($STATION_LATITUDE): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$STATION_LATITUDE" ]; then
            echo "Station latitude must be specified!"
            exit 8
        fi
    else
        STATION_LATITUDE=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note--  This is given in decimal degrees EAST (-179.99 to 180.00) -"
    echo "--Note--  Examples: -96.9 (96.9 degrees WEST), 112.71 (112.71 degrees EAST)"
    echo "Weather station longitude?"
    echo -n "($STATION_LONGITUDE): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$STATION_LONGITUDE" ]; then
            echo "Station longitude must be specified!"
            exit 8
        fi
    else
        STATION_LONGITUDE=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note--  DO NOT CHANGE this once you have archive records stored in /var/wview/archive"
    echo "--Note--      unless you delete all *.wlk files first!"
    echo "--Note--  This effects many things (CWOP/Wunderground update interval, etc.) so"
    echo "--Note--      choose it carefully and be prepared to stay with your choice!"
    echo "--Note--  If unsure what all this affects, CTRL-C to exit this script and do"
    echo "--Note--      a search for 'archive interval' in the wview User Manual..."
    echo "Weather data archive interval (minutes, one of 5, 10, 15, 30)?"
    echo -n "($STATION_ARCHIVE_INTERVAL): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        STATION_ARCHIVE_INTERVAL=$INVAL
    fi
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- currently only MySQL and PostgreSQL are supported"
echo "Should wviewd store archive data in a relational database (0 or 1)?"
echo -n "($DATABASE): "
read INVAL
if [ "" != "$INVAL" ]; then
    DATABASE=$INVAL
fi

if [ "$DATABASE" = "1" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note-- Do not enable unless you have installed extra sensors or have a VP Plus"
    echo "Should wviewd store extended sensor archive data in the database (0 or 1)?"
    echo -n "($DBEXTEND): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        DBEXTEND=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Should wviewd store metric (international) archive data in the database (0 or 1)?"
    echo -n "($DBMETRIC): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        DBMETRIC=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Hostname or IP address of the database server:"
    echo -n "($DBHOST): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$DBHOST" ]; then
            echo "Database host or IP address must be specified!"
            exit 8
        fi
    else
        DBHOST=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Username of the database server:"
    echo -n "($DBUSER): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$DBUSER" ]; then
            echo "Database username must be specified!"
            exit 8
        fi
    else
        DBUSER=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Password for $DBUSER on the database server:"
    echo -n "($DBPASSWD): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$DBPASSWD" ]; then
            echo "Database password must be specified!"
            exit 8
        fi
    else
        DBPASSWD=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Database name for weather records on the database server:"
    echo -n "($DBNAME): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$DBNAME" ]; then
            echo "Database table must be specified!"
            exit 8
        fi
    else
        DBNAME=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Table name for weather records on the database server:"
    echo -n "($DBTABLE): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$DBTABLE" ]; then
            echo "Database table must be specified!"
            exit 8
        fi
    else
        DBTABLE=$INVAL
    fi
fi

# Write out the conf file:
echo ""
if [ -f $WVIEW_CONF_DIR/wview.conf ]; then
    echo "Moving existing $WVIEW_CONF_DIR/wview.conf to $WVIEW_CONF_DIR/wview.conf.old..."
    mv $WVIEW_CONF_DIR/wview.conf $WVIEW_CONF_DIR/wview.conf.old
fi
echo ""
echo -n "Writing $WVIEW_CONF_DIR/wview.conf: "
mkdir -p $WVIEW_CONF_DIR

echo "#@" > $WVIEW_CONF_DIR/wview.conf
echo "#"  >> $WVIEW_CONF_DIR/wview.conf
echo "#  This file contains configuration information for the wview wviewd daemon."  >> $WVIEW_CONF_DIR/wview.conf
echo "#"  >> $WVIEW_CONF_DIR/wview.conf
echo "#  Note: For parameters that enable/disable a feature, a value of 0 disables"  >> $WVIEW_CONF_DIR/wview.conf
echo "#        the feature and 1 enables it..."  >> $WVIEW_CONF_DIR/wview.conf
echo "#"  >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo ""  >> $WVIEW_CONF_DIR/wview.conf
echo "##################### Station Configuration      #####################"  >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf
echo "# Physical interface to the weather station -"  >> $WVIEW_CONF_DIR/wview.conf
echo "# one of serial or ethernet:"  >> $WVIEW_CONF_DIR/wview.conf
echo "STATION_INTERFACE=$MEDIUM" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

# the next few depend on the medium selected
if [ "$MEDIUM" = "serial" ]; then
    echo "# Weather station serial device:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_DEV=$DEVNAME" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
elif [ "$MEDIUM" = "ethernet" ]; then
    echo "# Terminal server hostname/IP:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_HOST=$ETHHOST" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
    echo "# Terminal server TCP port to the weather station:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_PORT=$ETHPORT" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
fi

echo "# Station rain season start month (1 - 12):"  >> $WVIEW_CONF_DIR/wview.conf
echo "STATION_RAIN_SEASON_START=$RAIN_SEASON_START" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Station rain storm start trigger (rainfall rate in inches/hour):"  >> $WVIEW_CONF_DIR/wview.conf
echo "STATION_RAIN_STORM_TRIGGER_START=$STATION_RAIN_STORM_TRIGGER_START" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Station rain storm stop time (hours without any rainfall which will end the storm):"  >> $WVIEW_CONF_DIR/wview.conf
echo "STATION_RAIN_STORM_IDLE_STOP=$STATION_RAIN_STORM_IDLE_STOP" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo ""  >> $WVIEW_CONF_DIR/wview.conf
echo "##################### wviewd Configuration       #####################"  >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Where to store monthly Weather data archive files:"  >> $WVIEW_CONF_DIR/wview.conf
echo "ARCHIVE_PATH=$ARCPATH" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Weather station sensor poll interval (ms) - should be divisor of 60000:"  >> $WVIEW_CONF_DIR/wview.conf
echo "POLL_INTERVAL=$SENSORPOLL" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Current conditions data push interval for wvalarmd and possibly others (ms):"  >> $WVIEW_CONF_DIR/wview.conf
echo "PUSH_INTERVAL=$PUSHINT" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Daemon Verbose Log Mask:"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 1 bit per daemon, 1 enables verbose logging, 0 disables"  >> $WVIEW_CONF_DIR/wview.conf
echo "# Bit definitions:"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00000001     - wviewd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00000010     - htmlgend"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00000100     - wvalarmd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00001000     - wviewftpd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00010000     - wviewsshd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 00100000     - wvcwopd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 01000000     - wvwunderd"  >> $WVIEW_CONF_DIR/wview.conf
echo "# 11111111     - All On"  >> $WVIEW_CONF_DIR/wview.conf
echo "# Verbose diagnostic log messages per-daemon bitmask (8 characters, 0 or 1 only):"  >> $WVIEW_CONF_DIR/wview.conf
echo "VERBOSE_MSGS=$VERBOSE" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

# VantagePro Only
if [ "$STATION_TYPE" = "VantagePro" ]; then
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
    echo "##################### Vantage Pro Configuration  #####################"  >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
    echo "# Generate RX check data (populate rxCheck.png chart)?"  >> $WVIEW_CONF_DIR/wview.conf
    echo "DO_RXCHECK=$RXCHECK" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
fi

# Generic - non-VP
if [ "$STATION_TYPE" = "Generic" ]; then
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
    echo "##################### Generic Configuration      #####################"  >> $WVIEW_CONF_DIR/wview.conf
    echo "######## >For stations which do not maintain these settings< #########"  >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# Weather station elevation (feet above sea level):"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_ELEVATION=$STATION_ELEVATION" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# Weather station latitude (decimal degrees, EAST is positive - WEST is negative):"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_LATITUDE=$STATION_LATITUDE" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# Weather station longitude (decimal degrees, NORTH is positive - SOUTH is negative):"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_LONGITUDE=$STATION_LONGITUDE" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# DO NOT CHANGE this once you have archive records stored in /var/wview/archive!"  >> $WVIEW_CONF_DIR/wview.conf
    echo "# This effects many things (CWOP/Wunderground update interval, etc.) so choose carefully..."  >> $WVIEW_CONF_DIR/wview.conf
    echo "# Weather data archive interval (minutes, one of 5, 10, 15, 30):"  >> $WVIEW_CONF_DIR/wview.conf
    echo "STATION_ARCHIVE_INTERVAL=$STATION_ARCHIVE_INTERVAL" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
fi

echo ""  >> $WVIEW_CONF_DIR/wview.conf
echo "##################### SQL Database Configuration #####################"  >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

echo "# Enable SQL DB archive storage?"  >> $WVIEW_CONF_DIR/wview.conf
echo "SQLDB_ENABLE=$DATABASE" >> $WVIEW_CONF_DIR/wview.conf
echo ""  >> $WVIEW_CONF_DIR/wview.conf

if [ "$DATABASE" = "1" ]; then
    echo "# Store extended weather data (VP Plus only)?"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_EXTENDED_INFO=$DBEXTEND" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# Store metric values in the database?"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_STORE_METRIC=$DBMETRIC" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# DB server hostname or IP address:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_HOST=$DBHOST" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# DB server username:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_USERNAME=$DBUSER" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# DB server password:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_PASSWORD=$DBPASSWD" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# Database name where archive records are stored:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_DB_NAME=$DBNAME" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf

    echo "# DB table name where archive records are stored:"  >> $WVIEW_CONF_DIR/wview.conf
    echo "SQLDB_TABLE_NAME=$DBTABLE" >> $WVIEW_CONF_DIR/wview.conf
    echo ""  >> $WVIEW_CONF_DIR/wview.conf
fi

echo "done!"
echo ""
echo ""

################################################################################
echo "################################################################################"
echo "--> HTML Configuration ($WVIEW_CONF_DIR/htmlgen.conf):"
echo ""
echo "-------------------------------------------------------------" 
echo "Station Name (no spaces):"
echo -n "($STANAME): "
read INVAL
if [ "" = "$INVAL" ]; then
    if [ "changeME" = "$STANAME" ]; then
        echo "Station Name must be specified!"
        exit 9
    fi
else
    STANAME=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Station City (no spaces):"
echo -n "($STACITY): "
read INVAL
if [ "" = "$INVAL" ]; then
    if [ "changeME" = "$STACITY" ]; then
        echo "Station City must be specified!"
        exit 9
    fi
else
    STACITY=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Station State (no spaces):"
echo -n "($STASTATE): "
read INVAL
if [ "" = "$INVAL" ]; then
    if [ "changeME" = "$STASTATE" ]; then
        echo "Station State must be specified!"
        exit 9
    fi
else
    STASTATE=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- If your web server is on the same machine as wview, this should be the "
echo "--Note-- document root for your weather site. If you are going to ftp or ssh/rsync "
echo "--Note-- your site to a remote web server (such as your ISP), please use the "
echo "--Note-- default selection."
echo "Where to store generated web site graphics and HTML files:"
echo -n "($IMAGEPATH): "
read INVAL
if [ "" != "$INVAL" ]; then
    IMAGEPATH=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- Normal installs should use the default selection"
echo "Where to find HTML template files for web site generation:"
echo -n "($HTMLPATH): "
read INVAL
if [ "" != "$INVAL" ]; then
    HTMLPATH=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Generation start offset (0-4) in minutes past the 5-minute mark:"
echo -n "($GENOFFSET): "
read INVAL
if [ "" != "$INVAL" ]; then
    GENOFFSET=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Generation interval (refresh interval for your site data) (minutes):"
echo -n "($GENINT): "
read INVAL
if [ "" != "$INVAL" ]; then
    GENINT=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Enable metric conversion/units?"
echo -n "($GENMETRIC): "
read INVAL
if [ "" != "$INVAL" ]; then
    GENMETRIC=$INVAL
fi

if [ "0" != "$GENMETRIC" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Use mm for rain instead of cm?"
    echo -n "($METRIC_USE_RAIN_MM): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        METRIC_USE_RAIN_MM=$INVAL
    fi
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Store/process VP Plus extended sensor values for site generation?"
echo -n "($GENEXTEND): "
read INVAL
if [ "" != "$INVAL" ]; then
    GENEXTEND=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "--Note-- Each file contains one day's worth of archive records in ASCII format"
echo "--Note-- Special Values: -1 disables archive browser file generation and 0 keeps all files"
echo "How many archive record browser files to keep (days):"
echo -n "($RECSTOKEEP): "
read INVAL
if [ "" != "$INVAL" ]; then
    RECSTOKEEP=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Moon Phase increasing text (no spaces):"
echo -n "($MPHASEWAX): "
read INVAL
if [ "" != "$INVAL" ]; then
    MPHASEWAX=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Moon Phase decreasing text (no spaces):"
echo -n "($MPHASEWANE): "
read INVAL
if [ "" != "$INVAL" ]; then
    MPHASEWANE=$INVAL
fi

echo ""
echo "-------------------------------------------------------------" 
echo "Moon Phase full text (no spaces):"
echo -n "($MPHASEFULL): "
read INVAL
if [ "" != "$INVAL" ]; then
    MPHASEFULL=$INVAL
fi

# Write out the conf file:
echo ""
if [ -f $WVIEW_CONF_DIR/htmlgen.conf ]; then
    echo "Moving existing $WVIEW_CONF_DIR/htmlgen.conf to $WVIEW_CONF_DIR/htmlgen.conf.old..."
    mv $WVIEW_CONF_DIR/htmlgen.conf $WVIEW_CONF_DIR/htmlgen.conf.old
fi
echo ""
echo -n "Writing $WVIEW_CONF_DIR/htmlgen.conf: "

echo "#@" > $WVIEW_CONF_DIR/htmlgen.conf
echo "#"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "#  This file contains configuration information for the wview htmlgend daemon."  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "#"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "#  Note: For parameters that enable/disable a feature, a value of 0 disables"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "#        the feature and 1 enables it..."  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "#"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo "##################### Station Configuration      #####################"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Station Name:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "STATION_NAME=$STANAME" >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Station City:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "STATION_CITY=$STACITY" >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Station State:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "STATION_STATE=$STASTATE" >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf


echo "##################### htmlgend Configuration     #####################"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Where to store generated html and graphics files:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "IMAGE_PATH=$IMAGEPATH" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Where to find HTML template files:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "HTML_PATH=$HTMLPATH" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Generation start offset (0-4) in minutes:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "START_OFFSET=$GENOFFSET" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# How often to generate (refresh interval for your site data) in minutes:"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "GENERATE_INTERVAL=$GENINT" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Enable metric conversion/units?"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "METRIC_UNITS=$GENMETRIC" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# # If metric, use mm for rain instead of cm?"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "METRIC_USE_RAIN_MM=$METRIC_USE_RAIN_MM" >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Store/process VP Plus extended sensor values?"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "EXTENDED_DATA=$GENEXTEND" >> $WVIEW_CONF_DIR/htmlgen.conf
echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# How many archive record browser files to keep (-1 disables, 0 keeps all):"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "ARCHIVE_BROWSER_FILES_TO_KEEP=$RECSTOKEEP" >> $WVIEW_CONF_DIR/htmlgen.conf
#echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Moon Phase Text - configure text used for the 'Waxing/Waning %X Full' string"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Moon 'increasing' and 'decreasing' text"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "MPHASE_INCREASE=$MPHASEWAX" >> $WVIEW_CONF_DIR/htmlgen.conf
echo "MPHASE_DECREASE=$MPHASEWANE" >> $WVIEW_CONF_DIR/htmlgen.conf
echo "# Moon 'full' text"  >> $WVIEW_CONF_DIR/htmlgen.conf
echo "MPHASE_FULL=$MPHASEFULL" >> $WVIEW_CONF_DIR/htmlgen.conf
#echo ""  >> $WVIEW_CONF_DIR/htmlgen.conf

echo "done!"
echo ""
echo ""


################################################################################
echo "################################################################################"
echo "--> Optional wview Components"
echo ""
echo ""

if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
    DEFANS=1
else
    DEFANS=0
fi
echo "-------------------------------------------------------------" 
echo "Enable CWOP (Citizen Weather Observer Program) support?"
echo -n "($DEFANS): "
read INVAL
echo ""
if [ "" != "$INVAL" ]; then
    DEFANS=$INVAL
fi

if [ "1" = "$DEFANS" ]; then
    echo "################################################################################"
    echo "--> CWOP Configuration ($WVIEW_CONF_DIR/wvcwop.conf):"
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS Call Sign (6 characters, no spaces):"
    echo -n "($APRSSIGN): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$APRSSIGN" ]; then
            echo "APRS call sign must be specified!"
            exit 10
        fi
    else
        APRSSIGN=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note-- You MUST specify all 3 APRS servers - you can use the same server"
    echo "--Note-- for multiple entries, although this is highly discouraged - "
    echo "--Note-- See http://wxqa.com/activecwd.html for a list of servers"
    echo "APRS primary server name (hostname or IP address):"
    echo -n "($APRSSERVER1): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$APRSSERVER1" ]; then
            echo "APRS primary server must be specified!"
            exit 10
        fi
    else
        APRSSERVER1=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS primary port number (usually 23):"
    echo -n "($APRSPORT1): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        APRSPORT1=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS secondary server name (hostname or IP address):"
    echo -n "($APRSSERVER2): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$APRSSERVER2" ]; then
            echo "APRS server must be specified!"
            exit 10
        fi
    else
        APRSSERVER2=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS secondary port number (usually 23):"
    echo -n "($APRSPORT2): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        APRSPORT2=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS tertiary server name (hostname or IP address):"
    echo -n "($APRSSERVER3): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$APRSSERVER3" ]; then
            echo "APRS server must be specified!"
            exit 10
        fi
    else
        APRSSERVER3=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "APRS tertiary port number (usually 23):"
    echo -n "($APRSPORT3): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        APRSPORT3=$INVAL
    fi

    echo ""
    echo "See http://www.topozone.com/viewmaps.asp to get an accurate latitude and"
    echo "longitude for your station location..."

    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note-- LATITUDE MUST be of the form DDMM.hhd (LORAN format)"
    echo "--Note--   DD   - degrees (always positive and 2 digits)"
    echo "--Note--   MM   - minutes (00 - 59)"
    echo "--Note--   hh   - hundredths of minutes (00 - 99)"
    echo "--Note--   d    - hemisphere indicator (N or S)"
    echo "--Note-- See http://www.topozone.com/viewmaps.asp to get an accurate"
    echo "--Note-- latitude and longitude for your CWOP data"
    echo "Station latitude:"
    echo -n "($CWOPLAT): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$CWOPLAT" ]; then
            echo "CWOP Latitude must be specified!"
            exit 10
        fi
    else
        CWOPLAT=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "--Note-- LONGITUDE MUST be of the form DDDMM.hhd (LORAN format)"
    echo "--Note--   DDD  - degrees (always positive and 3 digits)"
    echo "--Note--   MM   - minutes (00 - 59)"
    echo "--Note--   hh   - hundredths of minutes (00 - 99)"
    echo "--Note--   d    - hemisphere indicator (E or W)"
    echo "Station longitude:"
    echo -n "($CWOPLONG): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$CWOPLONG" ]; then
            echo "CWOP Longitude must be specified!"
            exit 10
        fi
    else
        CWOPLONG=$INVAL
    fi

    echo ""
    echo "-------------------------------------------------------------" 
    echo "Log the APRS WX packet when sending?"
    echo -n "($CWOPLOGWX): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        CWOPLOGWX=$INVAL
    fi
    
    # Write out the wvcwop.conf file:
    echo ""
    if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
        echo "Moving existing $WVIEW_CONF_DIR/wvcwop.conf to $WVIEW_CONF_DIR/wvcwop.conf.old..."
        mv $WVIEW_CONF_DIR/wvcwop.conf $WVIEW_CONF_DIR/wvcwop.conf.old
    fi
    echo ""
    echo -n "Writing $WVIEW_CONF_DIR/wvcwop.conf: "
    
    echo "#@" > $WVIEW_CONF_DIR/wvcwop.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "#  This file contains configuration information for the wview CWOP daemon."  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "#  Note: For parameters that enable/disable a feature, a value of 0 disables"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "#        the feature and 1 enables it..."  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf
    
    echo "# APRS Call Sign:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_CALL_SIGN=$APRSSIGN" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Primary Server:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_SERVER1=$APRSSERVER1" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Primary Port Number:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_PORTNO1=$APRSPORT1" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Secondary Server:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_SERVER2=$APRSSERVER2" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Secondary Port Number:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_PORTNO2=$APRSPORT2" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Tertiary Server:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_SERVER3=$APRSSERVER3" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# APRS Tertiary Port Number:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "APRS_PORTNO3=$APRSPORT3" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# CWOP latitude:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "LATITUDE=$CWOPLAT" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# CWOP longitude:"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "LONGITUDE=$CWOPLONG" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "# Log APRS WX packets?"  >> $WVIEW_CONF_DIR/wvcwop.conf
    echo "LOG_WX_PACKET=$CWOPLOGWX" >> $WVIEW_CONF_DIR/wvcwop.conf
    echo ""  >> $WVIEW_CONF_DIR/wvcwop.conf

    echo "done."

else
    echo -n "Disabling the CWOP support by naming the config file $WVIEW_CONF_DIR/wvcwop.conf-no-cwop: "
    if [ -f $WVIEW_CONF_DIR/wvcwop.conf ]; then
        mv $WVIEW_CONF_DIR/wvcwop.conf $WVIEW_CONF_DIR/wvcwop.conf-no-cwop
        echo "done."
    elif [ -f $WVIEW_CONF_DIR/wvcwop.conf-no-cwop ]; then
        echo "CWOP support already disabled."
    else
        echo "$WVIEW_CONF_DIR/wvcwop.conf-no-cwop does not exist - thus disabled"
    fi
fi


if [ -f $WVIEW_CONF_DIR/wvwunder.conf ]; then
    DEFANS=1
else
    DEFANS=0
fi
echo "-------------------------------------------------------------"
echo "--Note-- You MUST enable WUNDERGROUND support with '--enable-wunderground' when ./configure was executed..."
echo "Enable WUNDERGROUND support?"
echo -n "($DEFANS): "
read INVAL
echo ""
if [ "" != "$INVAL" ]; then
    DEFANS=$INVAL
fi

if [ "1" = "$DEFANS" ]; then
    echo "################################################################################"
    echo "--> WUNDERGROUND Configuration ($WVIEW_CONF_DIR/wvwunder.conf):"
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Station ID (obtained when you registered with WUNDERGROUND):"
    echo -n "($WUNDERID): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$WUNDERID" ]; then
            echo "WUNDERGROUND station ID must be specified!"
            exit 11
        fi
    else
        WUNDERID=$INVAL
    fi
    
    echo ""
    echo "-------------------------------------------------------------" 
    echo "Password (obtained when you registered with WUNDERGROUND):"
    echo -n "($WUNDERPASSWD): "
    read INVAL
    if [ "" = "$INVAL" ]; then
        if [ "changeME" = "$WUNDERPASSWD" ]; then
            echo "WUNDERGROUND password must be specified!"
            exit 11
        fi
    else
        WUNDERPASSWD=$INVAL
    fi
    
    # Write out the wvwunder.conf file:
    echo ""
    if [ -f $WVIEW_CONF_DIR/wvwunder.conf ]; then
        echo "Moving existing $WVIEW_CONF_DIR/wvwunder.conf to $WVIEW_CONF_DIR/wvwunder.conf.old..."
        mv $WVIEW_CONF_DIR/wvwunder.conf $WVIEW_CONF_DIR/wvwunder.conf.old
    fi
    echo ""
    echo -n "Writing $WVIEW_CONF_DIR/wvwunder.conf: "
    
    echo "#@" > $WVIEW_CONF_DIR/wvwunder.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "#  This file contains configuration information for the wview WUNDERGROUND daemon."  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "#  Note: For parameters that enable/disable a feature, a value of 0 disables"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "#        the feature and 1 enables it..."  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "#"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo ""  >> $WVIEW_CONF_DIR/wvwunder.conf
    
    echo "# WUNDERGROUND Station ID:"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "STATIONID=$WUNDERID" >> $WVIEW_CONF_DIR/wvwunder.conf
    echo ""  >> $WVIEW_CONF_DIR/wvwunder.conf

    echo "# WUNDERGROUND password:"  >> $WVIEW_CONF_DIR/wvwunder.conf
    echo "PASSWORD=$WUNDERPASSWD" >> $WVIEW_CONF_DIR/wvwunder.conf
    echo ""  >> $WVIEW_CONF_DIR/wvwunder.conf

    echo "done."

else
    echo -n "Disabling the WUNDERGROUND support by naming the config file $WVIEW_CONF_DIR/wvwunder.conf-no-wunder: "
    if [ -f $WVIEW_CONF_DIR/wvwunder.conf ]; then
        mv $WVIEW_CONF_DIR/wvwunder.conf $WVIEW_CONF_DIR/wvwunder.conf-no-wunder
        echo "done."
    elif [ -f $WVIEW_CONF_DIR/wvwunder.conf-no-wunder ]; then
        echo "WUNDERGROUND support already disabled."
    else
        echo "$WVIEW_CONF_DIR/wvwunder.conf-no-wunder does not exist - thus disabled"
    fi
fi


echo ""
echo "-------------------------------------------------------------"
if [ -f $WVIEW_CONF_DIR/wvalarm.conf ]; then
    DEFANS=1
else
    DEFANS=0
fi
echo "Run the alarms daemon wvalarmd needed for alarm triggering or data feeds?"
echo -n "($DEFANS): "
read INVAL
echo ""
if [ "" != "$INVAL" ]; then
    DEFANS=$INVAL
fi

if [ "1" = "$DEFANS" ]; then
    echo -n "Enabling the alarm daemon by naming the config file $WVIEW_CONF_DIR/wvalarm.conf: "
    if [ -f $WVIEW_CONF_DIR/wvalarm.conf ]; then
        echo "file already exists - wvalarmd is enabled"
        echo "Remember to edit $WVIEW_CONF_DIR/wvalarm.conf if you want to define alarms..."
    elif [ -f $WVIEW_CONF_DIR/wvalarm.conf-no-alarms ]; then
        cp $WVIEW_CONF_DIR/wvalarm.conf-no-alarms $WVIEW_CONF_DIR/wvalarm.conf
        echo "done."
        echo "Remember to edit $WVIEW_CONF_DIR/wvalarm.conf if you want to define alarms..."
    else
        echo "The default (and disabled) distro file $WVIEW_CONF_DIR/wvalarm.conf-no-alarms does not exist!"
        echo "Did you use the install-env make target or copy the file manually?"
        echo "Alarms will be disabled until you copy the config files from the distro and re-run this script..."
    fi
else
    echo -n "Disabling the alarm daemon by naming the config file $WVIEW_CONF_DIR/wvalarm.conf-no-alarms: "
    if [ -f $WVIEW_CONF_DIR/wvalarm.conf ]; then
        mv $WVIEW_CONF_DIR/wvalarm.conf $WVIEW_CONF_DIR/wvalarm.conf-no-alarms
        echo "done."
    elif [ -f $WVIEW_CONF_DIR/wvalarm.conf-no-alarms ]; then
        echo "wvalarmd already disabled."
    else
        echo "$WVIEW_CONF_DIR/wvalarm.conf-no-alarms does not exist - thus disabled"
    fi
fi


echo ""
echo "-------------------------------------------------------------" 
if [ -f $WVIEW_CONF_DIR/wviewftp.conf ]; then
    DEFANS=1
else
    DEFANS=0
fi
echo "--Note-- Only needed if you plan to ftp your generated files to a remote web server or ISP account..."
echo "Run the ftp daemon wviewftpd?"
echo -n "($DEFANS): "
read INVAL
echo ""
if [ "" != "$INVAL" ]; then
    DEFANS=$INVAL
fi

if [ "1" = "$DEFANS" ]; then
    USEFTP=1
    echo -n "Enabling the ftp daemon by naming the config file $WVIEW_CONF_DIR/wviewftp.conf: "
    if [ -f $WVIEW_CONF_DIR/wviewftp.conf ]; then
        echo "file already exists - wviewftpd is enabled"
        echo "Remember to edit $WVIEW_CONF_DIR/wviewftp.conf to define files to transfer..."
    elif [ -f $WVIEW_CONF_DIR/wviewftp.conf-no-ftp ]; then
        cp $WVIEW_CONF_DIR/wviewftp.conf-no-ftp $WVIEW_CONF_DIR/wviewftp.conf
        echo "done."
        echo "Remember to edit $WVIEW_CONF_DIR/wviewftp.conf to define files to transfer..."
    else
        echo "The default (and disabled) distro file $WVIEW_CONF_DIR/wviewftp.conf-no-ftp does not exist!"
        echo "Did you use the install-env make target or copy the file manually?"
        echo "FTP will be disabled until you copy the config files from the distro and re-run this script..."
    fi
else
    USEFTP=0
    echo -n "Disabling the ftp daemon by naming the config file $WVIEW_CONF_DIR/wviewftp.conf-no-ftp: "
    if [ -f $WVIEW_CONF_DIR/wviewftp.conf ]; then
        mv $WVIEW_CONF_DIR/wviewftp.conf $WVIEW_CONF_DIR/wviewftp.conf-no-ftp
        echo "done."
    elif [ -f $WVIEW_CONF_DIR/wviewftp.conf-no-ftp ]; then
        echo "wviewftpd already disabled."
    else
        echo "$WVIEW_CONF_DIR/wviewftp.conf-no-ftp does not exist - thus disabled"
    fi
fi


if [ "1" != "$USEFTP" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    if [ -f $WVIEW_CONF_DIR/wviewssh.conf ]; then
        DEFANS=1
    else
        DEFANS=0
    fi
    echo "--Note-- Only needed if you plan to synchronize your generated files with a remote web server or ISP account..."
    echo "Run the rsync/ssh daemon wviewsshd?"
    echo -n "($DEFANS): "
    read INVAL
    echo ""
    if [ "" != "$INVAL" ]; then
        DEFANS=$INVAL
    fi

    if [ "1" = "$DEFANS" ]; then
        echo -n "Enabling the rsync/ssh daemon by naming the config file $WVIEW_CONF_DIR/wviewssh.conf: "
        if [ -f $WVIEW_CONF_DIR/wviewssh.conf ]; then
            echo "file already exists - wviewsshd is enabled"
            echo "Remember to edit $WVIEW_CONF_DIR/wviewssh.conf to define sync directories..."
        elif [ -f $WVIEW_CONF_DIR/wviewssh.conf-no-ssh ]; then
            cp $WVIEW_CONF_DIR/wviewssh.conf-no-ssh $WVIEW_CONF_DIR/wviewssh.conf
            echo "done."
            echo "Remember to edit $WVIEW_CONF_DIR/wviewssh.conf to define sync directories..."
        else
            echo "The default (and disabled) distro file $WVIEW_CONF_DIR/wviewssh.conf-no-ssh does not exist!"
            echo "Did you use the install-env make target or copy the file manually?"
            echo "rsync/ssh will be disabled until you copy the config files from the distro and re-run this script..."
        fi
    else
        echo -n "Disabling the rsync/ssh daemon by naming the config file $WVIEW_CONF_DIR/wviewssh.conf-no-ssh: "
        if [ -f $WVIEW_CONF_DIR/wviewssh.conf ]; then
            mv $WVIEW_CONF_DIR/wviewssh.conf $WVIEW_CONF_DIR/wviewssh.conf-no-ssh
            echo "done."
        elif [ -f $WVIEW_CONF_DIR/wviewssh.conf-no-ssh ]; then
            echo "wviewsshd already disabled."
        else
            echo "$WVIEW_CONF_DIR/wviewssh.conf-no-ssh does not exist - thus disabled"
        fi
    fi
fi

# VantagePro Only
if [ "$STATION_TYPE" = "VantagePro" ]; then
    echo ""
    echo "-------------------------------------------------------------" 
    if [ -f $WVIEW_CONF_DIR/forecast.conf ]; then
        DEFANS=1
    else
        DEFANS=0
    fi
    echo "--Note-- This will require 35 KB or more of memory..."
    echo "Enable the Vantage Pro Forecast icon support and Forecast Rule text support?"
    echo -n "($DEFANS): "
    read INVAL
    echo ""
    if [ "" != "$INVAL" ]; then
        DEFANS=$INVAL
    fi
    
    if [ "1" = "$DEFANS" ]; then
        echo -n "Enabling the forecast processing by naming the config file $WVIEW_CONF_DIR/forecast.conf: "
        if [ -f $WVIEW_CONF_DIR/forecast.conf ]; then
            echo "file already exists - forecast processing is enabled"
            echo "Remember to edit $WVIEW_CONF_DIR/forecast.conf to define icons and text..."
        elif [ -f $WVIEW_CONF_DIR/forecast.conf-no-forecast ]; then
            cp $WVIEW_CONF_DIR/forecast.conf-no-forecast $WVIEW_CONF_DIR/forecast.conf
            echo "done."
            echo "Remember to edit $WVIEW_CONF_DIR/forecast.conf to define icons and text..."
        else
            echo "The default (and disabled) distro file $WVIEW_CONF_DIR/forecast.conf-no-forecast does not exist!"
            echo "Did you use the install-env make target or copy the file manually?"
            echo "forecast processing will be disabled until you copy the config files from the distro and re-run this script..."
        fi
    else
        echo -n "Disabling the forecast processing by naming the config file $WVIEW_CONF_DIR/forecast.conf-no-forecast: "
        if [ -f $WVIEW_CONF_DIR/forecast.conf ]; then
            mv $WVIEW_CONF_DIR/forecast.conf $WVIEW_CONF_DIR/forecast.conf-no-forecast
            echo "done."
        elif [ -f $WVIEW_CONF_DIR/forecast.conf-no-forecast ]; then
            echo "forecast processing already disabled."
        else
            echo "$WVIEW_CONF_DIR/forecast.conf-no-forecast does not exist - thus disabled"
        fi
    fi
fi
if [ "$STATION_TYPE" = "Generic" ]; then
    if [ -f $WVIEW_CONF_DIR/forecast.conf ]; then
        mv $WVIEW_CONF_DIR/forecast.conf $WVIEW_CONF_DIR/forecast.conf-no-forecast
    fi
fi

echo ""
echo ""
echo "################################################################################"
echo "--> wview Configuration Complete!"
echo "################################################################################"
exit 0

